You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@sling.apache.org by ra...@apache.org on 2016/09/02 14:51:08 UTC

svn commit: r1758968 [1/2] - in /sling/trunk/bundles/scripting/sightly: ./ compiler/ compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/ compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/backend/ compiler/src/main/java/...

Author: radu
Date: Fri Sep  2 14:51:07 2016
New Revision: 1758968

URL: http://svn.apache.org/viewvc?rev=1758968&view=rev
Log:
SLING-6028 - Replace Sightly references with HTL in both code and documentation

Added:
    sling/trunk/bundles/scripting/sightly/models-use-provider/README.md
    sling/trunk/bundles/scripting/sightly/repl/src/main/resources/SLING-INF/etc/clientlibs/repl/images/htl.svg
    sling/trunk/bundles/scripting/sightly/repl/src/main/resources/SLING-INF/htl/
    sling/trunk/bundles/scripting/sightly/repl/src/main/resources/SLING-INF/htl/repl.json
Removed:
    sling/trunk/bundles/scripting/sightly/repl/src/main/resources/SLING-INF/etc/clientlibs/repl/images/sightly.svg
    sling/trunk/bundles/scripting/sightly/repl/src/main/resources/SLING-INF/sightly/repl.json
Modified:
    sling/trunk/bundles/scripting/sightly/NOTICE
    sling/trunk/bundles/scripting/sightly/README.md
    sling/trunk/bundles/scripting/sightly/compiler/README.md
    sling/trunk/bundles/scripting/sightly/compiler/pom.xml
    sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/RuntimeFunction.java
    sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/SightlyCompiler.java
    sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/backend/BackendCompiler.java
    sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/backend/package-info.java
    sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/commands/Command.java
    sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/commands/CommandStream.java
    sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/commands/Procedure.java
    sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/expression/Expression.java
    sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/expression/ExpressionNode.java
    sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/expression/nodes/TernaryOperator.java
    sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/util/VariableTracker.java
    sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/compiler/CompilerFrontend.java
    sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/compiler/Syntax.java
    sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/compiler/frontend/ExpressionParser.java
    sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/compiler/frontend/Interpolation.java
    sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/filter/URIManipulationFilter.java
    sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/html/dom/DocumentParser.java
    sling/trunk/bundles/scripting/sightly/compiler/src/test/java/org/apache/sling/scripting/sightly/impl/TestUtils.java
    sling/trunk/bundles/scripting/sightly/engine/README.md
    sling/trunk/bundles/scripting/sightly/engine/pom.xml
    sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/ResourceResolution.java
    sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/SightlyException.java
    sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/SightlyBindingsValuesProvider.java
    sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/SightlyEngineConfiguration.java
    sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/SightlyScriptEngine.java
    sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/SightlyScriptEngineFactory.java
    sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/compiled/SourceIdentifier.java
    sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/IncludeRuntimeExtension.java
    sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/ResourceRuntimeExtension.java
    sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/use/JavaUseProvider.java
    sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/use/RenderUnitProvider.java
    sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/use/ResourceUseProvider.java
    sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/use/ScriptUseProvider.java
    sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/runtime/RenderContextImpl.java
    sling/trunk/bundles/scripting/sightly/java-compiler/README.md
    sling/trunk/bundles/scripting/sightly/java-compiler/pom.xml
    sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/Record.java
    sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/extension/RuntimeExtension.java
    sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/java/compiler/RenderUnit.java
    sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/java/compiler/impl/VariableScope.java
    sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/pojo/Use.java
    sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/render/RenderContext.java
    sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/render/RuntimeObjectModel.java
    sling/trunk/bundles/scripting/sightly/js-use-provider/README.md
    sling/trunk/bundles/scripting/sightly/js-use-provider/pom.xml
    sling/trunk/bundles/scripting/sightly/js-use-provider/src/main/java/org/apache/sling/scripting/sightly/js/impl/JsUseProvider.java
    sling/trunk/bundles/scripting/sightly/js-use-provider/src/main/java/org/apache/sling/scripting/sightly/js/impl/jsapi/SlyBindingsValuesProvider.java
    sling/trunk/bundles/scripting/sightly/js-use-provider/src/main/java/org/apache/sling/scripting/sightly/js/impl/rhino/HybridObject.java
    sling/trunk/bundles/scripting/sightly/models-use-provider/pom.xml
    sling/trunk/bundles/scripting/sightly/models-use-provider/src/main/java/org/apache/sling/scripting/sightly/models/impl/SlingModelsUseProvider.java
    sling/trunk/bundles/scripting/sightly/pom.xml
    sling/trunk/bundles/scripting/sightly/repl/README.md
    sling/trunk/bundles/scripting/sightly/repl/pom.xml
    sling/trunk/bundles/scripting/sightly/repl/src/main/appended-resources/META-INF/LICENSE
    sling/trunk/bundles/scripting/sightly/repl/src/main/appended-resources/META-INF/NOTICE
    sling/trunk/bundles/scripting/sightly/repl/src/main/java/org/apache/sling/scripting/sightly/repl/REPLJavaSourceCodeServlet.java
    sling/trunk/bundles/scripting/sightly/repl/src/main/resources/SLING-INF/apps/repl/components/repl/repl.html
    sling/trunk/bundles/scripting/sightly/repl/src/main/resources/SLING-INF/apps/repl/components/repl/template.html
    sling/trunk/bundles/scripting/sightly/repl/src/main/resources/SLING-INF/etc/clientlibs/repl/style.css
    sling/trunk/bundles/scripting/sightly/testing-content/pom.xml
    sling/trunk/bundles/scripting/sightly/testing-content/src/main/resources/SLING-INF/apps/sightly/scripts/resource/resource.html
    sling/trunk/bundles/scripting/sightly/testing-content/src/main/resources/SLING-INF/apps/sightly/scripts/siblingdeps/component/component.html
    sling/trunk/bundles/scripting/sightly/testing-content/src/main/resources/SLING-INF/apps/sightly/scripts/use/javaerror.html
    sling/trunk/bundles/scripting/sightly/testing-content/src/main/resources/SLING-INF/apps/sightly/scripts/use/jsuse.html
    sling/trunk/bundles/scripting/sightly/testing-content/src/main/resources/SLING-INF/apps/sightly/scripts/use/repopojo.html
    sling/trunk/bundles/scripting/sightly/testing-content/src/main/resources/SLING-INF/apps/sightly/scripts/use/use.html
    sling/trunk/bundles/scripting/sightly/testing-content/src/main/resources/SLING-INF/apps/sightly/scripts/useinheritance/grandparent/grandparent.html
    sling/trunk/bundles/scripting/sightly/testing/pom.xml

Modified: sling/trunk/bundles/scripting/sightly/NOTICE
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/NOTICE?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/NOTICE (original)
+++ sling/trunk/bundles/scripting/sightly/NOTICE Fri Sep  2 14:51:07 2016
@@ -1,7 +1,7 @@
-Apache Sling Scripting Sightly bundles
+Apache Sling Scripting HTL bundles
 Copyright 2014 The Apache Software Foundation
 
-The Apache Sling Scripting Sightly bundles are based on source code originally developed
+The Apache Sling Scripting HTL bundles are based on source code originally developed
 by Adobe Systems Inc. (http://www.adobe.com/).
 
 This product includes software developed at

Modified: sling/trunk/bundles/scripting/sightly/README.md
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/README.md?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/README.md (original)
+++ sling/trunk/bundles/scripting/sightly/README.md Fri Sep  2 14:51:07 2016
@@ -1,15 +1,15 @@
-Apache Sling Scripting - Sightly implementation bundles
+Apache Sling Scripting - HTL implementation bundles
 ====
-These bundles provide support for the Sightly web templating language.
+These bundles provide support for the HTL web templating language.
 
 ## Contents
 1. `engine` - `org.apache.sling.scripting.sightly`
-  The Apache Sling Scripting Sightly Engine is a Java implementation of the Sightly specification. The bundle contains the Sightly 
+  The Apache Sling Scripting HTL Engine is a Java implementation of the HTL specification. The bundle contains the HTL 
   engine and its plugin framework implementation.
 2. `js-use-provider` - `org.apache.sling.scripting.sightly.js.provider`
-  The Apache Sling Sightly JavaScript Use Provider adds support for accessing JS scripts from Sightly's Use-API.
+  The Apache Sling HTL JavaScript Use Provider adds support for accessing JS scripts from Sightly's Use-API.
 3. `repl` - `org.apache.sling.scripting.sightly.repl`
-  A simple Read-Eval-Print-Loop environment for testing simple Sightly scripts
+  A simple Read-Eval-Print-Loop environment for testing simple HTL scripts
 4. `testing-content` - `org.apache.sling.scripting.sightly.testing-content`
   A bundle containing initial content for running integration tests
 5. `testing` - `org.apache.sling.scripting.sightly.testing`
@@ -27,7 +27,7 @@ mvn clean install
 mvn clean verify
 ```
 
-**Play with Sightly REPL**
+**Play with HTL REPL**
 ```bash
 cd testing
 mvn clean package slingstart:start -Dlaunchpad.keep.running=true -Dhttp.port=8080

Modified: sling/trunk/bundles/scripting/sightly/compiler/README.md
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/compiler/README.md?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/compiler/README.md (original)
+++ sling/trunk/bundles/scripting/sightly/compiler/README.md Fri Sep  2 14:51:07 2016
@@ -1,3 +1,3 @@
-Apache Sling Scripting Sightly Compiler
+Apache Sling Scripting HTL Compiler
 ====
-The Apache Sling Scripting Sightly Compiler provides support for compiling Sightly scripts into an Abstract Syntax Tree.
+The Apache Sling Scripting HTL Compiler provides support for compiling [HTML Template Language](https://github.com/Adobe-Marketing-Cloud/htl-spec) scripts into an Abstract Syntax Tree.

Modified: sling/trunk/bundles/scripting/sightly/compiler/pom.xml
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/compiler/pom.xml?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/compiler/pom.xml (original)
+++ sling/trunk/bundles/scripting/sightly/compiler/pom.xml Fri Sep  2 14:51:07 2016
@@ -36,10 +36,10 @@
     <version>0.0.1-SNAPSHOT</version>
     <packaging>bundle</packaging>
 
-    <name>Apache Sling Scripting Sightly Compiler</name>
+    <name>Apache Sling Scripting HTL Compiler</name>
 
     <description>
-        The Apache Sling Scripting Sightly Compiler provides support for compiling Sightly scripts into an Abstract
+        The Apache Sling Scripting HTL Compiler provides support for compiling HTML Template Language scripts into an Abstract
         Syntax Tree.
     </description>
 
@@ -156,14 +156,8 @@
                 <groupId>org.apache.maven.plugins</groupId>
                 <artifactId>maven-javadoc-plugin</artifactId>
                 <configuration>
-                    <groups>
-                        <group>
-                            <title>Sightly Template Engine Compiler</title>
-                            <packages>org.apache.sling.scripting.sightly</packages>
-                        </group>
-                    </groups>
-                    <doctitle>${project.name} Documentation (Version: ${project.version})</doctitle>
-                    <windowtitle>${project.name} Documentation (Version: ${project.version})</windowtitle>
+                    <stylesheet>maven</stylesheet>
+                    <excludePackageNames>*.impl:*.internal:${site.javadoc.exclude}</excludePackageNames>
                 </configuration>
             </plugin>
         </plugins>

Modified: sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/RuntimeFunction.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/RuntimeFunction.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/RuntimeFunction.java (original)
+++ sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/RuntimeFunction.java Fri Sep  2 14:51:07 2016
@@ -22,10 +22,10 @@ import java.util.Locale;
  * <p>
  *     This class documents what runtime functions (abstracted by
  *     {@link org.apache.sling.scripting.sightly.compiler.expression.nodes.RuntimeCall} expression nodes) will need to be available in a
- *     Sightly runtime.
+ *     HTL runtime.
  * </p>
  * <p>
- *     A Sightly runtime can only be defined through a {@link org.apache.sling.scripting.sightly.compiler.backend.BackendCompiler}
+ *     A HTL runtime can only be defined through a {@link org.apache.sling.scripting.sightly.compiler.backend.BackendCompiler}
  *     that can transpile {@link org.apache.sling.scripting.sightly.compiler.expression.nodes.RuntimeCall}s to specific runtime function
  *     implementations.
  * </p>
@@ -43,7 +43,7 @@ public final class RuntimeFunction {
      *     </ol>
      * </p>
      * <p>
-     *     For more details check https://github.com/Adobe-Marketing-Cloud/sightly-spec/blob/1.2/SPECIFICATION.md#122-format.
+     *     For more details check https://github.com/Adobe-Marketing-Cloud/htl-spec/blob/1.2/SPECIFICATION.md#122-format.
      * </p>
      */
     public static final String FORMAT = "format";
@@ -62,7 +62,7 @@ public final class RuntimeFunction {
      *     </ol>
      * </p>
      * <p>
-     *     For more details check https://github.com/Adobe-Marketing-Cloud/sightly-spec/blob/1.2/SPECIFICATION.md#123-i18n.
+     *     For more details check https://github.com/Adobe-Marketing-Cloud/htl-spec/blob/1.2/SPECIFICATION.md#123-i18n.
      * </p>
      */
     public static final String I18N = "i18n";
@@ -78,7 +78,7 @@ public final class RuntimeFunction {
      *     </ol>
      * </p>
      * <p>
-     *     For more details check https://github.com/Adobe-Marketing-Cloud/sightly-spec/blob/1.2/SPECIFICATION.md#124-array-join.
+     *     For more details check https://github.com/Adobe-Marketing-Cloud/htl-spec/blob/1.2/SPECIFICATION.md#124-array-join.
      * </p>
      */
     public static final String JOIN = "join";
@@ -94,7 +94,7 @@ public final class RuntimeFunction {
      *     </ol>
      * </p>
      * <p>
-     *     For more details check https://github.com/Adobe-Marketing-Cloud/sightly-spec/blob/1.2/SPECIFICATION.md#125-uri-manipulation.
+     *     For more details check https://github.com/Adobe-Marketing-Cloud/htl-spec/blob/1.2/SPECIFICATION.md#125-uri-manipulation.
      * </p>
      */
     public static final String URI_MANIPULATION = "uriManipulation";
@@ -110,7 +110,7 @@ public final class RuntimeFunction {
      *     </ol>
      * </p>
      * <p>
-     *     For more details check https://github.com/Adobe-Marketing-Cloud/sightly-spec/blob/1.2/SPECIFICATION.md#121-display-context.
+     *     For more details check https://github.com/Adobe-Marketing-Cloud/htl-spec/blob/1.2/SPECIFICATION.md#121-display-context.
      * </p>
      */
     public static final String XSS = "xss";
@@ -127,7 +127,7 @@ public final class RuntimeFunction {
      * </p>
      * <p>
      *     For more details about the supported options check
-     *     https://github.com/Adobe-Marketing-Cloud/sightly-spec/blob/1.2/SPECIFICATION.md#228-include.
+     *     https://github.com/Adobe-Marketing-Cloud/htl-spec/blob/1.2/SPECIFICATION.md#228-include.
      * </p>
      */
     public static final String INCLUDE = "include";
@@ -144,7 +144,7 @@ public final class RuntimeFunction {
      * </p>
      * <p>
      *     For more details about the supported options check
-     *     https://github.com/Adobe-Marketing-Cloud/sightly-spec/blob/1.2/SPECIFICATION.md#229-resource.
+     *     https://github.com/Adobe-Marketing-Cloud/htl-spec/blob/1.2/SPECIFICATION.md#229-resource.
      * </p>
      */
     public static final String RESOURCE = "includeResource";
@@ -160,7 +160,7 @@ public final class RuntimeFunction {
      *     </ol>
      * </p>
      * <p>
-     *     For more details check https://github.com/Adobe-Marketing-Cloud/sightly-spec/blob/1.2/SPECIFICATION.md#221-use.
+     *     For more details check https://github.com/Adobe-Marketing-Cloud/htl-spec/blob/1.2/SPECIFICATION.md#221-use.
      * </p>
      */
     public static final String USE = "use";

Modified: sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/SightlyCompiler.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/SightlyCompiler.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/SightlyCompiler.java (original)
+++ sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/SightlyCompiler.java Fri Sep  2 14:51:07 2016
@@ -64,7 +64,7 @@ import org.apache.sling.scripting.sightl
 
 /**
  * <p>
- * The {@link SightlyCompiler} interprets a Sightly script and transforms it internally into a {@link CommandStream}. The
+ * The {@link SightlyCompiler} interprets a HTL script and transforms it internally into a {@link CommandStream}. The
  * {@link CommandStream} can be fed to a {@link BackendCompiler} for transforming the stream into executable code, either by
  * transpiling the commands to a JVM supported language or by directly executing them.
  * </p>

Modified: sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/backend/BackendCompiler.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/backend/BackendCompiler.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/backend/BackendCompiler.java (original)
+++ sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/backend/BackendCompiler.java Fri Sep  2 14:51:07 2016
@@ -28,7 +28,7 @@ import aQute.bnd.annotation.ConsumerType
 
 /**
  * <p>
- *     A {@link BackendCompiler} can be hooked in into the {@link SightlyCompiler} in order to transpile Sightly {@link Command}s into other
+ *     A {@link BackendCompiler} can be hooked in into the {@link SightlyCompiler} in order to transpile HTL {@link Command}s into other
  *     JVM supported languages. The transpilation can be performed with the help of specific {@link CommandVisitor} implementations that are
  *     attached to the {@link Command}s from the {@link CommandStream}.
  * </p>

Modified: sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/backend/package-info.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/backend/package-info.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/backend/package-info.java (original)
+++ sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/backend/package-info.java Fri Sep  2 14:51:07 2016
@@ -18,8 +18,8 @@
  ******************************************************************************/
 
 /**
- * The {@code org.apache.sling.scripting.sightly.compiler.backend} defines the API that can be used by Sightly Backend Compilers, used to
- * compile Sightly {@link org.apache.sling.scripting.sightly.compiler.commands.Command}s into executable code for other languages.
+ * The {@code org.apache.sling.scripting.sightly.compiler.backend} defines the API that can be used by HTL Backend Compilers, used to
+ * compile HTL {@link org.apache.sling.scripting.sightly.compiler.commands.Command}s into executable code for other languages.
  */
 @Version("1.0.0")
 package org.apache.sling.scripting.sightly.compiler.backend;

Modified: sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/commands/Command.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/commands/Command.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/commands/Command.java (original)
+++ sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/commands/Command.java Fri Sep  2 14:51:07 2016
@@ -21,7 +21,7 @@ package org.apache.sling.scripting.sight
 import aQute.bnd.annotation.ProviderType;
 
 /**
- * A {@code Command} represents the type of instruction a certain Sightly expression or block element should execute. Commands are immutable
+ * A {@code Command} represents the type of instruction a certain HTL expression or block element should execute. Commands are immutable
  * and can only be processed through a {@link CommandVisitor}.
  */
 @ProviderType

Modified: sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/commands/CommandStream.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/commands/CommandStream.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/commands/CommandStream.java (original)
+++ sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/commands/CommandStream.java Fri Sep  2 14:51:07 2016
@@ -24,7 +24,7 @@ import aQute.bnd.annotation.ProviderType
 
 /**
  * <p>
- *     This interface defines a stream to which {@link Command}s are pushed during the compilation of a Sightly script by the {@link
+ *     This interface defines a stream to which {@link Command}s are pushed during the compilation of a HTL script by the {@link
  *     org.apache.sling.scripting.sightly.compiler.SightlyCompiler}. Depending on how a consumer wants to use the stream there are several
  *     options:
  *      <ul>

Modified: sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/commands/Procedure.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/commands/Procedure.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/commands/Procedure.java (original)
+++ sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/commands/Procedure.java Fri Sep  2 14:51:07 2016
@@ -23,7 +23,7 @@ import java.util.HashSet;
 import java.util.Set;
 
 /**
- * This {@link Command} allows defining a Sightly template - the only functional construct of the language.
+ * This {@link Command} allows defining a HTL template - the only functional construct of the language.
  */
 public class Procedure {
 

Modified: sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/expression/Expression.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/expression/Expression.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/expression/Expression.java (original)
+++ sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/expression/Expression.java Fri Sep  2 14:51:07 2016
@@ -25,7 +25,7 @@ import java.util.Map;
 import org.apache.sling.scripting.sightly.compiler.expression.nodes.BinaryOperation;
 
 /**
- * This class represents a Sightly Expression.
+ * This class represents a HTL Expression.
  */
 public final class Expression {
 

Modified: sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/expression/ExpressionNode.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/expression/ExpressionNode.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/expression/ExpressionNode.java (original)
+++ sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/expression/ExpressionNode.java Fri Sep  2 14:51:07 2016
@@ -21,7 +21,7 @@ package org.apache.sling.scripting.sight
 import aQute.bnd.annotation.ProviderType;
 
 /**
- * Defines a node in a Sightly expression tree.
+ * Defines a node in a HTL expression tree.
  */
 @ProviderType
 public interface ExpressionNode {

Modified: sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/expression/nodes/TernaryOperator.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/expression/nodes/TernaryOperator.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/expression/nodes/TernaryOperator.java (original)
+++ sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/expression/nodes/TernaryOperator.java Fri Sep  2 14:51:07 2016
@@ -23,7 +23,7 @@ import org.apache.sling.scripting.sightl
 import org.apache.sling.scripting.sightly.compiler.expression.NodeVisitor;
 
 /**
- * Defines the Sightly ternary operator (e.g. {@code condition ? then : else}).
+ * Defines the HTL ternary operator (e.g. {@code condition ? then : else}).
  */
 public final class TernaryOperator implements ExpressionNode {
 

Modified: sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/util/VariableTracker.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/util/VariableTracker.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/util/VariableTracker.java (original)
+++ sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/compiler/util/VariableTracker.java Fri Sep  2 14:51:07 2016
@@ -24,7 +24,7 @@ import java.util.Map;
 import java.util.Stack;
 
 /**
- * Tracks information related to Sightly variables, at different levels of the compiler.
+ * Tracks information related to HTL variables, at different levels of the compiler.
  */
 public final class VariableTracker<T> {
 

Modified: sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/compiler/CompilerFrontend.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/compiler/CompilerFrontend.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/compiler/CompilerFrontend.java (original)
+++ sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/compiler/CompilerFrontend.java Fri Sep  2 14:51:07 2016
@@ -19,7 +19,7 @@
 package org.apache.sling.scripting.sightly.impl.compiler;
 
 /**
- * Sightly compiler frontend.
+ * HTL compiler frontend.
  */
 public interface CompilerFrontend {
 

Modified: sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/compiler/Syntax.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/compiler/Syntax.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/compiler/Syntax.java (original)
+++ sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/compiler/Syntax.java Fri Sep  2 14:51:07 2016
@@ -23,7 +23,7 @@ import java.util.Arrays;
 import org.apache.sling.scripting.sightly.impl.plugin.PluginCallInfo;
 
 /**
- * Sightly Syntax specific elements.
+ * HTL Syntax specific elements.
  */
 public class Syntax {
 
@@ -40,9 +40,9 @@ public class Syntax {
     public static final String CONTEXT_OPTION = "context";
 
     /**
-     * Checks whether a piece of text represents a Sightly comment
+     * Checks whether a piece of text represents a HTL comment
      * @param text - the text
-     * @return - true if it is a Sightly comment, false otherwise
+     * @return - true if it is a HTL comment, false otherwise
      */
     public static boolean isSightlyComment(String text) {
         String trimmed = text.trim();

Modified: sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/compiler/frontend/ExpressionParser.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/compiler/frontend/ExpressionParser.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/compiler/frontend/ExpressionParser.java (original)
+++ sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/compiler/frontend/ExpressionParser.java Fri Sep  2 14:51:07 2016
@@ -30,7 +30,7 @@ public class ExpressionParser {
     /**
      * Parses the expression string.
      *
-     * @param expressionString as defined by the Sightly spec (https://github.com/Adobe-Marketing-Cloud/sightly-spec/blob/master/SPECIFICATION.md)
+     * @param expressionString as defined by the HTL spec (https://github.com/Adobe-Marketing-Cloud/htl-spec/blob/master/SPECIFICATION.md)
      * @return Parsed Expression object
      * @throws NullPointerException     is the given exprString is null
      * @throws SightlyCompilerException if an error occurs while parsing the expression

Modified: sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/compiler/frontend/Interpolation.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/compiler/frontend/Interpolation.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/compiler/frontend/Interpolation.java (original)
+++ sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/compiler/frontend/Interpolation.java Fri Sep  2 14:51:07 2016
@@ -24,7 +24,7 @@ import java.util.List;
 import org.apache.sling.scripting.sightly.compiler.expression.Expression;
 
 /**
- * A sequence with alternating string fragments and Sightly expressions. These result from parsing HTML attributes or string nodes. For
+ * A sequence with alternating string fragments and HTL expressions. These result from parsing HTML attributes or string nodes. For
  * instance "Hello ${World}!" would result in 3 fragments: "Hello ", ${World} and "!"
  */
 public class Interpolation {

Modified: sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/filter/URIManipulationFilter.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/filter/URIManipulationFilter.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/filter/URIManipulationFilter.java (original)
+++ sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/filter/URIManipulationFilter.java Fri Sep  2 14:51:07 2016
@@ -28,7 +28,7 @@ import org.apache.sling.scripting.sightl
 
 /**
  * The {@code URIManipulationFilter} provides support for Sightly's URI Manipulation options according to the
- * <a href="https://github.com/Adobe-Marketing-Cloud/sightly-spec/blob/1.2/SPECIFICATION.md">language specification</a>
+ * <a href="https://github.com/Adobe-Marketing-Cloud/htl-spec/blob/1.2/SPECIFICATION.md">language specification</a>
  */
 public class URIManipulationFilter extends AbstractFilter {
 

Modified: sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/html/dom/DocumentParser.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/html/dom/DocumentParser.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/html/dom/DocumentParser.java (original)
+++ sling/trunk/bundles/scripting/sightly/compiler/src/main/java/org/apache/sling/scripting/sightly/impl/html/dom/DocumentParser.java Fri Sep  2 14:51:07 2016
@@ -46,7 +46,7 @@ public class DocumentParser {
             TreeTraverser tree = new TreeTraverser(handler);
             tree.traverse(template);
         } catch (IOException e) {
-            LOGGER.error("Failed to parse Sightly template", e);
+            LOGGER.error("Failed to parse HTL template", e);
         }
     }
 }

Modified: sling/trunk/bundles/scripting/sightly/compiler/src/test/java/org/apache/sling/scripting/sightly/impl/TestUtils.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/compiler/src/test/java/org/apache/sling/scripting/sightly/impl/TestUtils.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/compiler/src/test/java/org/apache/sling/scripting/sightly/impl/TestUtils.java (original)
+++ sling/trunk/bundles/scripting/sightly/compiler/src/test/java/org/apache/sling/scripting/sightly/impl/TestUtils.java Fri Sep  2 14:51:07 2016
@@ -25,7 +25,7 @@ import java.io.Reader;
 import org.apache.sling.scripting.sightly.compiler.CompilationUnit;
 
 /**
- * Testing static utilities that simplify writing tests for the Sightly compiler.
+ * Testing static utilities that simplify writing tests for the HTL compiler.
  */
 public class TestUtils {
 

Modified: sling/trunk/bundles/scripting/sightly/engine/README.md
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/engine/README.md?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/engine/README.md (original)
+++ sling/trunk/bundles/scripting/sightly/engine/README.md Fri Sep  2 14:51:07 2016
@@ -1,4 +1,5 @@
-Apache Sling Scripting Sightly Engine
+Apache Sling Scripting HTL Engine
 ====
 
-This package contains a Java implementation of the [Sightly templating language specification](https://github.com/Adobe-Marketing-Cloud/sightly-spec).
+This package contains a Java implementation of the [HTML Template Language specification](https://github
+.com/Adobe-Marketing-Cloud/htl-spec).

Modified: sling/trunk/bundles/scripting/sightly/engine/pom.xml
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/engine/pom.xml?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/engine/pom.xml (original)
+++ sling/trunk/bundles/scripting/sightly/engine/pom.xml Fri Sep  2 14:51:07 2016
@@ -36,11 +36,11 @@
     <version>1.0.19-SNAPSHOT</version>
     <packaging>bundle</packaging>
 
-    <name>Apache Sling Scripting Sightly Engine</name>
+    <name>Apache Sling Scripting HTL Engine</name>
 
     <description>
-        The Apache Sling Scripting Sightly Engine is a Java implementation of the Sightly specification. The bundle contains the Sightly
-        engine and its plugin framework implementation.
+        The Apache Sling Scripting HTL Engine is a Java implementation of the HTML Template Language specification. The bundle contains the
+        HTL script engine and its runtime implementation.
     </description>
 
     <scm>
@@ -124,14 +124,8 @@
                 <groupId>org.apache.maven.plugins</groupId>
                 <artifactId>maven-javadoc-plugin</artifactId>
                 <configuration>
-                    <groups>
-                        <group>
-                            <title>Sightly Template Engine</title>
-                            <packages>org.apache.sling.scripting.sightly.api</packages>
-                        </group>
-                    </groups>
-                    <doctitle>${project.name} Documentation (Version: ${project.version})</doctitle>
-                    <windowtitle>${project.name} Documentation (Version: ${project.version})</windowtitle>
+                    <stylesheet>maven</stylesheet>
+                    <excludePackageNames>*.impl:*.internal:${site.javadoc.exclude}</excludePackageNames>
                 </configuration>
             </plugin>
         </plugins>
@@ -141,7 +135,7 @@
     <!-- D E P E N D E N C I E S                                                 -->
     <!-- ======================================================================= -->
     <dependencies>
-        <!-- Sightly Compilers -->
+        <!-- HTL Compilers -->
         <dependency>
             <groupId>org.apache.sling</groupId>
             <artifactId>org.apache.sling.scripting.sightly.compiler</artifactId>

Modified: sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/ResourceResolution.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/ResourceResolution.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/ResourceResolution.java (original)
+++ sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/ResourceResolution.java Fri Sep  2 14:51:07 2016
@@ -26,7 +26,7 @@ import org.apache.sling.api.resource.Res
 import org.apache.sling.api.resource.ResourceUtil;
 
 /**
- * Utility class which used by the Sightly engine &amp; extensions to resolve resources.
+ * Utility class which used by the HTL engine &amp; extensions to resolve resources.
  */
 public final class ResourceResolution {
 

Modified: sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/SightlyException.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/SightlyException.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/SightlyException.java (original)
+++ sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/SightlyException.java Fri Sep  2 14:51:07 2016
@@ -21,7 +21,7 @@ package org.apache.sling.scripting.sight
 import org.apache.sling.api.SlingException;
 
 /**
- * Exceptions caused by the Sightly engine
+ * Exceptions caused by the HTL engine
  */
 public class SightlyException extends SlingException {
 

Modified: sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/SightlyBindingsValuesProvider.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/SightlyBindingsValuesProvider.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/SightlyBindingsValuesProvider.java (original)
+++ sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/SightlyBindingsValuesProvider.java Fri Sep  2 14:51:07 2016
@@ -31,7 +31,7 @@ import org.apache.sling.scripting.api.Bi
 import org.apache.sling.scripting.sightly.impl.utils.BindingsUtils;
 
 /**
- * Sightly specific {@code BindingsValuesProvider}.
+ * HTL specific {@code BindingsValuesProvider}.
  */
 @Component()
 @Service(BindingsValuesProvider.class)

Modified: sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/SightlyEngineConfiguration.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/SightlyEngineConfiguration.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/SightlyScriptEngine.java (original)
+++ sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/SightlyScriptEngine.java Fri Sep  2 14:51:07 2016
@@ -48,7 +48,7 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 /**
- * The Sightly Script engine
+ * The HTL Script engine
  */
 public class SightlyScriptEngine extends AbstractSlingScriptEngine implements Compilable {
 

Modified: sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/SightlyScriptEngineFactory.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/SightlyScriptEngineFactory.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/compiled/SourceIdentifier.java (original)
+++ sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/compiled/SourceIdentifier.java Fri Sep  2 14:51:07 2016
@@ -30,7 +30,7 @@ import org.apache.sling.scripting.sightl
 
 /**
  * Identifies a Java source file based on a {@link Resource}. Depending on the used constructor this class might provide the abstraction
- * for either a Java source file generated for a Sightly HTML script or for a Sightly {@link Resource}-based Java Use-API Object.
+ * for either a Java source file generated for a HTL script or for a HTL {@link Resource}-based Java Use-API Object.
  */
 public class SourceIdentifier implements ClassInfo {
 

Modified: sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/IncludeRuntimeExtension.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/IncludeRuntimeExtension.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/IncludeRuntimeExtension.java (original)
+++ sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/IncludeRuntimeExtension.java Fri Sep  2 14:51:07 2016
@@ -43,7 +43,7 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 /**
- * Runtime support for including resources in a Sightly script through {@code data-sly-include}.
+ * Runtime support for including resources in a HTL script through {@code data-sly-include}.
  */
 @Component
 @Service(RuntimeExtension.class)

Modified: sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/ResourceRuntimeExtension.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/ResourceRuntimeExtension.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/ResourceRuntimeExtension.java (original)
+++ sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/ResourceRuntimeExtension.java Fri Sep  2 14:51:07 2016
@@ -46,7 +46,7 @@ import org.apache.sling.scripting.sightl
 import org.apache.sling.scripting.sightly.render.RenderContext;
 
 /**
- * Runtime support for including resources in a Sightly script through {@code data-sly-resource}.
+ * Runtime support for including resources in a HTL script through {@code data-sly-resource}.
  */
 @Component
 @Service(RuntimeExtension.class)

Modified: sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/use/JavaUseProvider.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/use/JavaUseProvider.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/use/JavaUseProvider.java (original)
+++ sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/use/JavaUseProvider.java Fri Sep  2 14:51:07 2016
@@ -46,7 +46,7 @@ import org.slf4j.LoggerFactory;
 
 @Component(
         metatype = true,
-        label = "Apache Sling Scripting Sightly Java Use Provider",
+        label = "Apache Sling Scripting HTL Java Use Provider",
         description = "The Java Use Provider is responsible for instantiating Java Use-API objects."
 )
 @Service(UseProvider.class)

Modified: sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/use/RenderUnitProvider.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/use/RenderUnitProvider.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/use/ResourceUseProvider.java (original)
+++ sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/use/ResourceUseProvider.java Fri Sep  2 14:51:07 2016
@@ -35,7 +35,7 @@ import org.osgi.framework.Constants;
 
 @Component(
         metatype = true,
-        label = "Apache Sling Scripting Sightly Resource Use Provider",
+        label = "Apache Sling Scripting HTL Resource Use Provider",
         description = "The Java Use Provider is responsible for instantiating resource objects."
 )
 @Service(UseProvider.class)

Modified: sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/use/ScriptUseProvider.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/use/ScriptUseProvider.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/use/ScriptUseProvider.java (original)
+++ sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/use/ScriptUseProvider.java Fri Sep  2 14:51:07 2016
@@ -48,7 +48,7 @@ import org.slf4j.LoggerFactory;
  */
 @Component(
         metatype = true,
-        label = "Apache Sling Scripting Sightly Script Use Provider",
+        label = "Apache Sling Scripting HTL Script Use Provider",
         description = "The Script Use Provider is responsible for instantiating objects from scripts evaluated by other Sling Scripting " +
                 "Engines."
 )

Modified: sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/runtime/RenderContextImpl.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/runtime/RenderContextImpl.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/runtime/RenderContextImpl.java (original)
+++ sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/runtime/RenderContextImpl.java Fri Sep  2 14:51:07 2016
@@ -37,7 +37,7 @@ import org.apache.sling.scripting.sightl
 import org.apache.sling.scripting.sightly.render.RuntimeObjectModel;
 
 /**
- * Rendering context for Sightly rendering units.
+ * Rendering context for HTL rendering units.
  */
 public class RenderContextImpl implements RenderContext {
 

Modified: sling/trunk/bundles/scripting/sightly/java-compiler/README.md
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/java-compiler/README.md?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/java-compiler/README.md (original)
+++ sling/trunk/bundles/scripting/sightly/java-compiler/README.md Fri Sep  2 14:51:07 2016
@@ -1,4 +1,4 @@
-Apache Sling Scripting Sightly Java Compiler
-====
-The Apache Sling Scripting Sightly Java Compiler provides support for transpiling the Abstract Syntax Tree produced by the
+Apache Sling Scripting HTL Java Compiler
+========================================
+The Apache Sling Scripting HTL Java Compiler provides support for transpiling the Abstract Syntax Tree produced by the
 [`org.apache.sling.scripting.sightly.compiler`](../compiler) module into Java source code.

Modified: sling/trunk/bundles/scripting/sightly/java-compiler/pom.xml
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/java-compiler/pom.xml?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/java-compiler/pom.xml (original)
+++ sling/trunk/bundles/scripting/sightly/java-compiler/pom.xml Fri Sep  2 14:51:07 2016
@@ -34,10 +34,10 @@
     <version>0.0.1-SNAPSHOT</version>
     <packaging>bundle</packaging>
 
-    <name>Apache Sling Scripting Sightly Java Compiler</name>
+    <name>Apache Sling Scripting HTL Java Compiler</name>
 
     <description>
-        The Apache Sling Scripting Sightly Java Compiler provides support for transpiling the Abstract Syntax Tree produced by the
+        The Apache Sling Scripting HTL Java Compiler provides support for transpiling the Abstract Syntax Tree produced by the
         org.apache.sling.scripting.sightly.compiler module into Java source code.
     </description>
 
@@ -119,14 +119,8 @@
                 <groupId>org.apache.maven.plugins</groupId>
                 <artifactId>maven-javadoc-plugin</artifactId>
                 <configuration>
-                    <groups>
-                        <group>
-                            <title>Apache Sling Scriptin Sightly Java Compiler</title>
-                            <packages>org.apache.sling.scripting.sightly.compiler.java</packages>
-                        </group>
-                    </groups>
-                    <doctitle>${project.name} Documentation (Version: ${project.version})</doctitle>
-                    <windowtitle>${project.name} Documentation (Version: ${project.version})</windowtitle>
+                    <stylesheet>maven</stylesheet>
+                    <excludePackageNames>*.impl:*.internal:${site.javadoc.exclude}</excludePackageNames>
                 </configuration>
             </plugin>
         </plugins>

Modified: sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/Record.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/Record.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/Record.java (original)
+++ sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/Record.java Fri Sep  2 14:51:07 2016
@@ -24,7 +24,7 @@ import java.util.Set;
 import aQute.bnd.annotation.ConsumerType;
 
 /**
- * A {@code Record} is a key-value immutable object understood by the Sightly runtime, used for abstracting complex objects like Sightly
+ * A {@code Record} is a key-value immutable object understood by the HTL runtime, used for abstracting complex objects like Sightly
  * templates (declared with the {@code data-sly-template} block element) or objects that need to be translated from Java to JavaScript
  * and back.
  *

Modified: sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/extension/RuntimeExtension.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/extension/RuntimeExtension.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/extension/RuntimeExtension.java (original)
+++ sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/extension/RuntimeExtension.java Fri Sep  2 14:51:07 2016
@@ -23,7 +23,7 @@ import org.apache.sling.scripting.sightl
 import aQute.bnd.annotation.ConsumerType;
 
 /**
- * A {@code RuntimeExtension} represents a Sightly runtime construct that provides some processing capabilities for the various
+ * A {@code RuntimeExtension} represents a HTL runtime construct that provides some processing capabilities for the various
  * {@code data-sly-*} block elements.
  */
 @ConsumerType

Modified: sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/java/compiler/RenderUnit.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/java/compiler/RenderUnit.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/java/compiler/RenderUnit.java (original)
+++ sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/java/compiler/RenderUnit.java Fri Sep  2 14:51:07 2016
@@ -70,13 +70,13 @@ public abstract class RenderUnit impleme
             }
             if (renderContext.getObjectModel().isPrimitive(templateObj)) {
                 throw new SightlyJavaCompilerException(
-                        "data-sly-call: primitive \"" + templateObj.toString() + "\" does not represent a Sightly template.");
+                        "data-sly-call: primitive \"" + templateObj.toString() + "\" does not represent a HTL template.");
             } else if (templateObj instanceof String) {
                 throw new SightlyJavaCompilerException(
-                        "data-sly-call: String '" + templateObj.toString() + "' does not represent a Sightly template.");
+                        "data-sly-call: String '" + templateObj.toString() + "' does not represent a HTL template.");
             }
             throw new SightlyJavaCompilerException(
-                    "data-sly-call: " + templateObj.getClass().getName() + " does not represent a Sightly template.");
+                    "data-sly-call: " + templateObj.getClass().getName() + " does not represent a HTL template.");
         }
         RenderUnit unit = (RenderUnit) templateObj;
         Map<String, Object> argumentsMap = renderContext.getObjectModel().toMap(argsObj);

Modified: sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/java/compiler/impl/VariableScope.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/java/compiler/impl/VariableScope.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/java/compiler/impl/VariableScope.java (original)
+++ sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/java/compiler/impl/VariableScope.java Fri Sep  2 14:51:07 2016
@@ -18,7 +18,7 @@
 package org.apache.sling.scripting.sightly.java.compiler.impl;
 
 /**
- * The scope of a variable in a Sightly script
+ * The scope of a variable in a HTL script
  */
 public enum VariableScope {
     DYNAMIC, SCOPED, GLOBAL

Modified: sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/pojo/Use.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/pojo/Use.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/pojo/Use.java (original)
+++ sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/pojo/Use.java Fri Sep  2 14:51:07 2016
@@ -26,7 +26,7 @@ import aQute.bnd.annotation.ConsumerType
  * The <code>Use</code> interface can be implemented by Java objects which are instantiated as part of processing {@code data-sly-use}
  * attributes.
  *
- * @see <a href="https://github.com/Adobe-Marketing-Cloud/sightly-spec/blob/master/SPECIFICATION.md#221-use">Sightly Block Statements - Use</a>
+ * @see <a href="https://github.com/Adobe-Marketing-Cloud/htl-spec/blob/master/SPECIFICATION.md#221-use">HTL Block Statements - Use</a>
  */
 @ConsumerType
 public interface Use {
@@ -36,7 +36,7 @@ public interface Use {
      * Called to initialize the Java object with the current Java Scripting API bindings.
      * </p>
      * <p/>
-     * This method is called only if the object has been instantiated by Sightly as part of processing the {@code data-sly-use}
+     * This method is called only if the object has been instantiated by HTL as part of processing the {@code data-sly-use}
      * attribute. The Java Scripting API bindings provide all the global variables known to a script being executed.
      * <p/>
      *

Modified: sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/render/RenderContext.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/render/RenderContext.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/render/RenderContext.java (original)
+++ sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/render/RenderContext.java Fri Sep  2 14:51:07 2016
@@ -23,7 +23,7 @@ import org.apache.sling.scripting.sightl
 import aQute.bnd.annotation.ProviderType;
 
 /**
- * The {@code RenderContext} defines the context for executing Sightly scripts.
+ * The {@code RenderContext} defines the context for executing HTL scripts.
  */
 @ProviderType
 public interface RenderContext {
@@ -36,7 +36,7 @@ public interface RenderContext {
     RuntimeObjectModel getObjectModel();
 
     /**
-     * Returns the map of script bindings available to Sightly scripts.
+     * Returns the map of script bindings available to HTL scripts.
      *
      * @return the global bindings for a script
      */

Modified: sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/render/RuntimeObjectModel.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/render/RuntimeObjectModel.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/render/RuntimeObjectModel.java (original)
+++ sling/trunk/bundles/scripting/sightly/java-compiler/src/main/java/org/apache/sling/scripting/sightly/render/RuntimeObjectModel.java Fri Sep  2 14:51:07 2016
@@ -23,7 +23,7 @@ import aQute.bnd.annotation.ProviderType
 
 /**
  * The {@code RuntimeObjectModel} provides various utility object inspection &amp; conversion methods that can be applied to runtime
- * objects when executing Sightly scripts.
+ * objects when executing HTL scripts.
  */
 @ProviderType
 public interface RuntimeObjectModel {

Modified: sling/trunk/bundles/scripting/sightly/js-use-provider/README.md
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/js-use-provider/README.md?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/js-use-provider/README.md (original)
+++ sling/trunk/bundles/scripting/sightly/js-use-provider/README.md Fri Sep  2 14:51:07 2016
@@ -1,8 +1,6 @@
-Apache Sling Scripting Sightly JavaScript Use Provider
-=====================================
+Apache Sling Scripting HTL JavaScript Use Provider
+==================================================
 
-This bundle allows Sightly's USE API to access JS scripts. It also wraps Sling's JS engine in a simulated event loop.
+This bundle allows HTL's Use API to access JS scripts. It also wraps Sling's JS engine in a simulated event loop.
 
-The bundle also contains a bindings values provider that adds an API layer accessible from Sightly & JS.
-
-The implementation of that API can be found in `src/main/resources/SLING-INF`.
+The bundle also contains a bindings values provider that adds an API layer accessible from HTL & JS. The implementation of that API can be found in `src/main/resources/SLING-INF`.

Modified: sling/trunk/bundles/scripting/sightly/js-use-provider/pom.xml
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/js-use-provider/pom.xml?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/js-use-provider/pom.xml (original)
+++ sling/trunk/bundles/scripting/sightly/js-use-provider/pom.xml Fri Sep  2 14:51:07 2016
@@ -36,10 +36,10 @@
     <version>1.0.11-SNAPSHOT</version>
     <packaging>bundle</packaging>
 
-    <name>Apache Sling Scripting Sightly JavaScript Use Provider</name>
+    <name>Apache Sling Scripting HTL JavaScript Use Provider</name>
 
     <description>
-        The Apache Sling Sightly JavaScript Use Provider adds support for accessing JS scripts from Sightly's Use-API.
+        The Apache Sling HTL JavaScript Use Provider adds support for accessing JS scripts from HTL's Use-API.
     </description>
 
     <scm>
@@ -113,7 +113,7 @@
             <scope>provided</scope>
         </dependency>
 
-        <!-- Sightly -->
+        <!-- HTL -->
         <dependency>
             <groupId>org.apache.sling</groupId>
             <artifactId>org.apache.sling.scripting.sightly</artifactId>

Modified: sling/trunk/bundles/scripting/sightly/js-use-provider/src/main/java/org/apache/sling/scripting/sightly/js/impl/JsUseProvider.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/js-use-provider/src/main/java/org/apache/sling/scripting/sightly/js/impl/JsUseProvider.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/js-use-provider/src/main/java/org/apache/sling/scripting/sightly/js/impl/JsUseProvider.java (original)
+++ sling/trunk/bundles/scripting/sightly/js-use-provider/src/main/java/org/apache/sling/scripting/sightly/js/impl/JsUseProvider.java Fri Sep  2 14:51:07 2016
@@ -45,7 +45,7 @@ import org.osgi.framework.Constants;
  */
 @Component(
     metatype = true,
-    label = "Apache Sling Scripting Sightly JavaScript Use Provider",
+    label = "Apache Sling Scripting HTL JavaScript Use Provider",
     description = "The JavaScript Use Provider is responsible for instantiating JavaScript Use-API objects."
 )
 @Service(UseProvider.class)

Modified: sling/trunk/bundles/scripting/sightly/js-use-provider/src/main/java/org/apache/sling/scripting/sightly/js/impl/jsapi/SlyBindingsValuesProvider.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/js-use-provider/src/main/java/org/apache/sling/scripting/sightly/js/impl/jsapi/SlyBindingsValuesProvider.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/js-use-provider/src/main/java/org/apache/sling/scripting/sightly/js/impl/rhino/HybridObject.java (original)
+++ sling/trunk/bundles/scripting/sightly/js-use-provider/src/main/java/org/apache/sling/scripting/sightly/js/impl/rhino/HybridObject.java Fri Sep  2 14:51:07 2016
@@ -29,7 +29,7 @@ import org.mozilla.javascript.Scriptable
 
 
 /**
- * Instances of this class can be used in both Sightly &amp; JavaScript scripts.
+ * Instances of this class can be used in both HTL &amp; JavaScript scripts.
  */
 public class HybridObject implements Scriptable, Record<Object> {
 

Added: sling/trunk/bundles/scripting/sightly/models-use-provider/README.md
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/models-use-provider/README.md?rev=1758968&view=auto
==============================================================================
--- sling/trunk/bundles/scripting/sightly/models-use-provider/README.md (added)
+++ sling/trunk/bundles/scripting/sightly/models-use-provider/README.md Fri Sep  2 14:51:07 2016
@@ -0,0 +1,6 @@
+Apache Sling Scripting HTL Sling Models Use Provider
+==================================================
+
+The Apache Sling Scripting HTL Sling Models Use Provider adds support for accessing
+[Sling Models](https://sling.apache.org/documentation/bundles/models.html)
+from HTL's Use-API leveraging the `ModelFactory`.

Modified: sling/trunk/bundles/scripting/sightly/models-use-provider/pom.xml
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/models-use-provider/pom.xml?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/models-use-provider/pom.xml (original)
+++ sling/trunk/bundles/scripting/sightly/models-use-provider/pom.xml Fri Sep  2 14:51:07 2016
@@ -36,10 +36,11 @@
     <version>1.0.1-SNAPSHOT</version>
     <packaging>bundle</packaging>
 
-    <name>Apache Sling Scripting Sightly Models Use Provider</name>
+    <name>Apache Sling Scripting HTL Sling Models Use Provider</name>
 
     <description>
-        Apache Sling Scripting Sightly Models Use Provider adds support for accessing Sling Models from Sightly's Use-API leveraging the ModelFactory.
+        Apache Sling Scripting HTL Sling Models Use Provider adds support for accessing Sling Models from HTL's Use-API leveraging the
+        ModelFactory.
     </description>
 
     <scm>
@@ -96,7 +97,7 @@
             <scope>provided</scope>
         </dependency>
 
-        <!-- Sightly -->
+        <!-- HTL -->
         <dependency>
             <groupId>org.apache.sling</groupId>
             <artifactId>org.apache.sling.scripting.sightly.compiler.java</artifactId>

Modified: sling/trunk/bundles/scripting/sightly/models-use-provider/src/main/java/org/apache/sling/scripting/sightly/models/impl/SlingModelsUseProvider.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/models-use-provider/src/main/java/org/apache/sling/scripting/sightly/models/impl/SlingModelsUseProvider.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/pom.xml (original)
+++ sling/trunk/bundles/scripting/sightly/pom.xml Fri Sep  2 14:51:07 2016
@@ -37,10 +37,10 @@
     <version>1.0.0-SNAPSHOT</version>
     <packaging>pom</packaging>
 
-    <name>Apache Sling Scripting Sightly Reactor</name>
+    <name>Apache Sling Scripting HTL Reactor</name>
 
     <description>
-        The Apache Sling Scripting Sightly Reactor project.
+        The Apache Sling Scripting HTL Reactor project.
     </description>
 
     <scm>

Modified: sling/trunk/bundles/scripting/sightly/repl/README.md
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/repl/README.md?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/repl/README.md (original)
+++ sling/trunk/bundles/scripting/sightly/repl/README.md Fri Sep  2 14:51:07 2016
@@ -1,4 +1,4 @@
-Apache Sling Scripting Sightly Read-Eval-Print Loop Environment
+Apache Sling Scripting HTL Read-Eval-Print Loop Environment
 ====
 
 To install:
@@ -6,6 +6,6 @@ To install:
 mvn clean install sling:install
 ```
 
-Then just browse to [http://localhost:8080/sightly/repl.html](http://localhost:8080/sightly/repl.html).
+Then just browse to [http://localhost:8080/htl/repl.html](http://localhost:8080/htl/repl.html).
 
 

Modified: sling/trunk/bundles/scripting/sightly/repl/pom.xml
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/repl/pom.xml?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/repl/pom.xml (original)
+++ sling/trunk/bundles/scripting/sightly/repl/pom.xml Fri Sep  2 14:51:07 2016
@@ -30,8 +30,8 @@
     <version>1.0.3-SNAPSHOT</version>
     <packaging>bundle</packaging>
 
-    <name>Apache Sling Scripting Sightly Read-Eval-Print Loop Environment</name>
-    <description>REPL for Apache Sling Scripting Sightly engine</description>
+    <name>Apache Sling Scripting HTL Read-Eval-Print Loop Environment</name>
+    <description>REPL for Apache Sling Scripting HTL engine</description>
 
     <scm>
         <connection>scm:svn:http://svn.apache.org/repos/asf/sling/trunk/bundles/scripting/sightly/repl</connection>

Modified: sling/trunk/bundles/scripting/sightly/repl/src/main/appended-resources/META-INF/LICENSE
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/repl/src/main/appended-resources/META-INF/LICENSE?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/repl/src/main/appended-resources/META-INF/LICENSE (original)
+++ sling/trunk/bundles/scripting/sightly/repl/src/main/appended-resources/META-INF/LICENSE Fri Sep  2 14:51:07 2016
@@ -1,4 +1,4 @@
-Apache Sling Scripting Sightly Read-Eval-Print-Loop Environment sub-components:
+Apache Sling Scripting HTL Read-Eval-Print-Loop Environment sub-components:
 
 The following sub-components are not Apache 2 licensed:
 

Modified: sling/trunk/bundles/scripting/sightly/repl/src/main/appended-resources/META-INF/NOTICE
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/repl/src/main/appended-resources/META-INF/NOTICE?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/repl/src/main/appended-resources/META-INF/NOTICE (original)
+++ sling/trunk/bundles/scripting/sightly/repl/src/main/appended-resources/META-INF/NOTICE Fri Sep  2 14:51:07 2016
@@ -1,2 +1,2 @@
-The Apache Sling Sightly REPL bundle is based on source code originally developed
+The Apache Sling HTL REPL bundle is based on source code originally developed
 by Adobe Systems Inc. (http://www.adobe.com/).

Modified: sling/trunk/bundles/scripting/sightly/repl/src/main/java/org/apache/sling/scripting/sightly/repl/REPLJavaSourceCodeServlet.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/repl/src/main/java/org/apache/sling/scripting/sightly/repl/REPLJavaSourceCodeServlet.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/repl/src/main/java/org/apache/sling/scripting/sightly/repl/REPLJavaSourceCodeServlet.java (original)
+++ sling/trunk/bundles/scripting/sightly/repl/src/main/java/org/apache/sling/scripting/sightly/repl/REPLJavaSourceCodeServlet.java Fri Sep  2 14:51:07 2016
@@ -91,7 +91,7 @@ public class REPLJavaSourceCodeServlet e
             }
             LOGGER.warn("Source code for " + (classesFolder.isDirectory() ? classesFolder.getAbsolutePath() : "") +
                     "/org/apache/sling/scripting/sightly/apps/repl/components/repl/template_html.java was not found. Maybe you need to " +
-                    "configure the Sightly Scripting Engine to keep the generated source files?");
+                    "configure the HTL Scripting Engine to keep the generated source files?");
         }
         return "";
     }
--- sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/SightlyEngineConfiguration.java (original)
+++ sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/SightlyEngineConfiguration.java Fri Sep  2 14:51:07 2016
@@ -34,12 +34,12 @@ import org.apache.sling.commons.osgi.Pro
 import org.osgi.service.component.ComponentContext;
 
 /**
  * Holds various Sightly engine global configurations.
  */
 @Component(
         metatype = true,
-        label = "Apache Sling Scripting Sightly Engine Configuration",
-        description = "Sightly Engine Configuration Options"
+        label = "Apache Sling Scripting HTL Engine Configuration",
+        description = "HTL Engine Configuration Options"
 )
 @Service(SightlyEngineConfiguration.class)
 @Properties({
@@ -47,7 +47,7 @@ import org.osgi.service.component.Compon
                 name = SightlyEngineConfiguration.SCR_PROP_NAME_KEEPGENERATED,
                 boolValue = SightlyEngineConfiguration.SCR_PROP_DEFAULT_KEEPGENERATED,
                 label = "Keep Generated Java Source Code",
-                description = "If enabled, the Java source code generated during Sightly template files compilation will be stored. " +
+                description = "If enabled, the Java source code generated during HTL template files compilation will be stored. " +
                         "Its location is dependent on the available org.apache.sling.commons.classloader.ClassLoaderWriter."
         )
 })
@@ -34,12 +34,12 @@ import org.apache.sling.commons.osgi.Pro
 
 /**
- * Holds various Sightly engine global configurations.
+ * Holds various HTL engine global configurations.
  */
 @Component(

Modified: sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/SightlyScriptEngine.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/SightlyScriptEngine.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/SightlyScriptEngineFactory.java (original)
+++ sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/SightlyScriptEngineFactory.java Fri Sep  2 14:51:07 2016
@@ -40,12 +40,12 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 /**
  * Sightly template engine factory
  */
 @Component()
 @Service(ScriptEngineFactory.class)
 @Properties({
-        @Property(name = "service.description", value = "Sightly Templating Engine"),
+        @Property(name = "service.description", value = "HTL Templating Engine"),
         @Property(name = "compatible.javax.script.name", value = "sly")
 })
 public class SightlyScriptEngineFactory extends AbstractScriptEngineFactory {
@@ -69,7 +69,7 @@ public class SightlyScriptEngineFactory
 
     public final static String SHORT_NAME = "sightly";
 
-    public final static String LANGUAGE_NAME = "The Sightly Templating Language";
+    public final static String LANGUAGE_NAME = "The HTL Templating Language";
 
     public final static String LANGUAGE_VERSION = "1.0";
 
@@ -114,7 +114,7 @@ public class SightlyScriptEngineFactory
                 if (newVersionString.equals(versionInfo)) {
                     newVersion = false;
                 } else {
-                    LOGGER.info("Detected stale classes generated by Apache Sling Scripting Sightly engine version {}.", versionInfo);
+                    LOGGER.info("Detected stale classes generated by Apache Sling Scripting HTL engine version {}.", versionInfo);
                 }
                 IOUtils.closeQuietly(is);
             }
@@ -134,7 +134,7 @@ public class SightlyScriptEngineFactory
             boolean scratchFolderDeleted = classLoaderWriter.delete(scratchFolder);
             if (scratchFolderDeleted) {
                 if (StringUtils.isNotEmpty(versionInfo)) {
-                    LOGGER.info("Deleted stale classes generated by Apache Sling Scripting Sightly engine version {}.", versionInfo);
+                    LOGGER.info("Deleted stale classes generated by Apache Sling Scripting HTL engine version {}.", versionInfo);
                 }
             }
         }
@@ -40,12 +40,12 @@ import org.slf4j.Logger;
 
 /**
- * Sightly template engine factory
+ * HTL template engine factory
  */
 @Component()

Modified: sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/compiled/SourceIdentifier.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/compiled/SourceIdentifier.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/use/RenderUnitProvider.java (original)
+++ sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/use/RenderUnitProvider.java Fri Sep  2 14:51:07 2016
@@ -50,12 +50,12 @@ import org.apache.sling.scripting.sightl
 import org.osgi.framework.Constants;
 
 /**
  * Interprets identifiers as paths to other Sightly templates
  */
 @Component(
         metatype = true,
-        label = "Apache Sling Scripting Sightly Render Unit Use Provider",
-        description = "The Render Unit Use Provider is responsible for instantiating Sightly templates through the Use-API."
+        label = "Apache Sling Scripting HTL Render Unit Use Provider",
+        description = "The Render Unit Use Provider is responsible for instantiating HTL templates through the Use-API."
 )
 @Service(UseProvider.class)
 @Properties({
@@ -50,12 +50,12 @@ import org.apache.sling.scripting.sightl
 
 /**
- * Interprets identifiers as paths to other Sightly templates
+ * Interprets identifiers as paths to other HTL templates
  */
 @Component(

Modified: sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/use/ResourceUseProvider.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/engine/src/main/java/org/apache/sling/scripting/sightly/impl/engine/extension/use/ResourceUseProvider.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/js-use-provider/src/main/java/org/apache/sling/scripting/sightly/js/impl/jsapi/SlyBindingsValuesProvider.java (original)
+++ sling/trunk/bundles/scripting/sightly/js-use-provider/src/main/java/org/apache/sling/scripting/sightly/js/impl/jsapi/SlyBindingsValuesProvider.java Fri Sep  2 14:51:07 2016
@@ -65,10 +65,10 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 /**
  * Provides the {@code sightly} namespace for usage in Sightly &amp; JS scripts called from Sightly
  */
-@Component(metatype = true, label = "Apache Sling Scripting Sightly JavaScript Bindings Provider",
-        description = "The Apache Sling Scripting Sightly JavaScript Bindings Provider loads the JS Use-API and makes it available in the" +
+@Component(metatype = true, label = "Apache Sling Scripting HTL JavaScript Bindings Provider",
+        description = "The Apache Sling Scripting HTL JavaScript Bindings Provider loads the JS Use-API and makes it available in the" +
                 " bindings map.")
 @Service(SlyBindingsValuesProvider.class)
 @Properties({
@@ -65,10 +65,10 @@ import org.slf4j.Logger;
 
 /**
- * Provides the {@code sightly} namespace for usage in Sightly &amp; JS scripts called from Sightly
+ * Provides the {@code sightly} namespace for usage in HTL &amp; JS scripts called from Sightly
  */

Modified: sling/trunk/bundles/scripting/sightly/js-use-provider/src/main/java/org/apache/sling/scripting/sightly/js/impl/rhino/HybridObject.java
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/js-use-provider/src/main/java/org/apache/sling/scripting/sightly/js/impl/rhino/HybridObject.java?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================
--- sling/trunk/bundles/scripting/sightly/models-use-provider/src/main/java/org/apache/sling/scripting/sightly/models/impl/SlingModelsUseProvider.java (original)
+++ sling/trunk/bundles/scripting/sightly/models-use-provider/src/main/java/org/apache/sling/scripting/sightly/models/impl/SlingModelsUseProvider.java Fri Sep  2 14:51:07 2016
@@ -41,7 +41,7 @@ import org.slf4j.LoggerFactory;
 
 /**
  * <p>
  * Sightly {@link UseProvider} which will instantiate a referenced Sling Model.
  * </p>
  * <p>
  * For that it tries to use the {@link ModelFactory#createModel(Object, Class)} first with the adaptable {@link SlingHttpServletRequest}
@@ -59,7 +59,7 @@ import org.slf4j.LoggerFactory;
  */
 @Component(
     metatype = true,
-    label = "Apache Sling Scripting Sightly Sling Models Use Provider",
+    label = "Apache Sling Scripting HTL Sling Models Use Provider",
     description = "The Sling Models Use Provider is responsible for instantiating Sling Models to be used with Sightly's Use-API."
 )
 @Service
@@ -41,7 +41,7 @@ import org.slf4j.LoggerFactory;
 /**
  * <p>
- * Sightly {@link UseProvider} which will instantiate a referenced Sling Model.
+ * HTL {@link UseProvider} which will instantiate a referenced Sling Model.
  * </p>
  * <p>

Modified: sling/trunk/bundles/scripting/sightly/pom.xml
URL: http://svn.apache.org/viewvc/sling/trunk/bundles/scripting/sightly/pom.xml?rev=1758968&r1=1758967&r2=1758968&view=diff
==============================================================================